import {
  StylesConfig,
  CSSObjectWithLabel,
  ControlProps,
  OptionProps,
} from "react-select";
import { ContactIcon } from "@/icons";

interface SelectOption {
  label: string;
  value: string;
}

export const NAVIGATION_ITEMS = [
  {
    title: "Home",
    link: "/",
  },
  {
    title: "About Us",
    link: "/aboutus",
  },
  {
    title: "Ayurvedic Treatments",
    link: "/ayurveda",
  },
  {
    title: "Rooms & Suites",
    link: "/rooms",
  },
  {
    title: "Restaurant & Bar",
    link: "/restaurent",
  },
  {
    title: "Contact Us",
    link: "/contactus",
  },
];

export const ADMIN_NAVIGATION_ITEMS = [
  // {
  //   title: "Dashboard",
  //   link: "/admin",
  //   icon: DashboardIcon,
  //   children: 0,
  // },
  // {
  //   title: "Suppliers",
  //   link: "/admin/suppliers",
  //   icon: DashboardIcon,
  //   children: 0,
  // },
  {
    title: "Requests",
    link: "/admin/contact",
    icon: ContactIcon,
    children: 0,
  },
];

export const TABLE_HEADER_STYLES = {
  headCells: {
    style: {
      font: "Poppins",
      fontWeight: "600",
      color: "#64728C",
      fontSize: "14px",
    },
  },
  cells: {
    style: {
      font: "Poppins",
      fontWeight: "normal",
      color: "#64728C",
      fontSize: "12px",
    },
  },
};

export const CUSTOM_SELECT_STYLES: StylesConfig<SelectOption, boolean> = {
  control: (
    base: CSSObjectWithLabel,
    state: ControlProps<SelectOption, boolean>
  ) => ({
    ...base,
    fontSize: "14px",
    fontWeight: 600,
    color: state.isFocused ? "#64728C" : "#64728C82",
    borderColor: state.isFocused ? "#64728C" : base.borderColor,
    boxShadow: state.isFocused ? "0 0 0 1px #64728C" : base.boxShadow,
    "&:hover": {
      borderColor: state.isFocused ? "#64728C" : base.borderColor,
    },
  }),
  option: (
    base: CSSObjectWithLabel,
    state: OptionProps<SelectOption, boolean>
  ) => ({
    ...base,
    color: state.isSelected ? "#64728C" : "#64728C",
    backgroundColor: state.isSelected ? "#e7e7e7" : "white",
    ":hover": {
      backgroundColor: state.isSelected ? "#ccc" : "#f3f3f3",
    },
    fontSize: "14px",
    fontWeight: 600,
  }),
  singleValue: (base: CSSObjectWithLabel) => ({
    ...base,
    color: "#64728C",
  }),
  placeholder: (base: CSSObjectWithLabel) => ({
    ...base,
    color: "#bdbdbd",
  }),
};

export const TABLE_HEAD_SUPPLIER = ["ID", "Name", "Email", "Contact No"];

export const ContactFormInputs = [
  {
    name: "Your Name (Name with Initial)*",
    inputName: "Name",
    type: "text",
  },
  {
    name: "Address*",
    inputName: "Address",
    type: "text",
  },
  {
    name: "Birthday*",
    inputName: "Birthday",
    type: "date",
  },
  {
    name: "Phone Number*",
    inputName: "Phone",
    type: "text",
  },
  {
    name: "E-mail Address*",
    inputName: "Email",
    type: "text",
  },
];
